@@ -1,5 +1,5 @@
-/* ANSI-C code produced by gperf version 3.0.4 */
-/* Command-line: gperf -m 10 ./unicase/locale-languages.gperf  */
+/* ANSI-C code produced by gperf version 3.2 */
+/* Command-line: gperf -m 10 ../../lib/unicase/locale-languages.gperf  */
 /* Computed positions: -k'1-3' */
 
 #if !((' ' == 32) && ('!' == 33) && ('"' == 34) && ('#' == 35) \
@@ -26,7 +26,7 @@
       && ('w' == 119) && ('x' == 120) && ('y' == 121) && ('z' == 122) \
       && ('{' == 123) && ('|' == 124) && ('}' == 125) && ('~' == 126))
 /* The character set is not based on ISO-646.  */
-#error "gperf generated tables don't work with this execution character set. Please report a bug to <bug-gnu-gperf@gnu.org>."
+#error "gperf generated tables don't work with this execution character set. Please report a bug to <bug-gperf@gnu.org>."
 #endif
 
 
@@ -45,7 +45,7 @@ inline
 #endif
 #endif
 static unsigned int
-uc_locale_language_hash (register const char *str, register unsigned int len)
+uc_locale_language_hash (register const char *str, register size_t len)
 {
   static const unsigned short asso_values[] =
     {
@@ -78,15 +78,25 @@ uc_locale_language_hash (register const char *str, register unsigned int len)
       462, 462, 462, 462, 462, 462, 462, 462, 462, 462,
       462, 462, 462
     };
-  register int hval = len;
+  register unsigned int hval = len;
 
   switch (hval)
     {
       default:
         hval += asso_values[(unsigned char)str[2]+2];
+#if defined __cplusplus && (__cplusplus >= 201703L || (__cplusplus >= 201103L && defined __clang_major__ && defined __clang_minor__ && __clang_major__ + (__clang_minor__ >= 9) > 3))
+      [[fallthrough]];
+#elif defined __GNUC__ && __GNUC__ >= 7
+      __attribute__ ((__fallthrough__));
+#endif
       /*FALLTHROUGH*/
       case 2:
         hval += asso_values[(unsigned char)str[1]+17];
+#if defined __cplusplus && (__cplusplus >= 201703L || (__cplusplus >= 201103L && defined __clang_major__ && defined __clang_minor__ && __clang_major__ + (__clang_minor__ >= 9) > 3))
+      [[fallthrough]];
+#elif defined __GNUC__ && __GNUC__ >= 7
+      __attribute__ ((__fallthrough__));
+#endif
       /*FALLTHROUGH*/
       case 1:
         hval += asso_values[(unsigned char)str[0]+3];
@@ -95,14 +105,8 @@ uc_locale_language_hash (register const char *str, register unsigned int len)
   return hval;
 }
 
-#ifdef __GNUC__
-__inline
-#if defined __GNUC_STDC_INLINE__ || defined __GNUC_GNU_INLINE__
-__attribute__ ((__gnu_inline__))
-#endif
-#endif
-const char *
-uc_locale_languages_lookup (register const char *str, register unsigned int len)
+static const char *
+uc_locale_languages_lookup (register const char *str, register size_t len)
 {
   struct stringpool_t
     {
@@ -670,358 +674,358 @@ uc_locale_languages_lookup (register const char *str, register unsigned int len)
   static const int wordlist[] =
     {
       -1, -1, -1, -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str4,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str5,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str6,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str7,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str8,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str4,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str5,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str6,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str7,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str8,
       -1, -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str11,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str12,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str13,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str14,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str15,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str16,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str17,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str18,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str19,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str11,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str12,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str13,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str14,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str15,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str16,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str17,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str18,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str19,
       -1, -1, -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str23,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str24,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str25,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str23,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str24,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str25,
       -1, -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str28,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str29,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str30,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str31,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str32,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str33,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str28,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str29,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str30,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str31,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str32,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str33,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str35,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str36,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str37,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str38,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str39,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str40,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str41,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str42,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str35,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str36,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str37,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str38,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str39,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str40,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str41,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str42,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str44,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str45,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str44,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str45,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str47,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str48,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str47,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str48,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str50,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str51,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str52,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str53,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str54,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str55,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str56,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str50,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str51,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str52,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str53,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str54,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str55,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str56,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str58,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str58,
       -1, -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str61,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str62,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str63,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str64,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str65,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str66,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str67,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str61,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str62,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str63,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str64,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str65,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str66,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str67,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str69,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str69,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str71,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str72,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str73,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str71,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str72,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str73,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str75,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str76,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str77,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str78,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str79,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str75,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str76,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str77,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str78,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str79,
       -1, -1, -1, -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str84,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str85,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str86,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str84,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str85,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str86,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str88,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str89,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str90,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str91,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str92,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str88,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str89,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str90,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str91,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str92,
       -1, -1, -1, -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str97,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str98,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str99,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str100,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str97,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str98,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str99,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str100,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str102,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str103,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str102,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str103,
       -1, -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str106,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str106,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str108,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str109,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str110,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str108,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str109,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str110,
       -1, -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str113,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str114,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str115,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str116,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str117,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str118,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str119,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str120,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str113,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str114,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str115,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str116,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str117,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str118,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str119,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str120,
       -1, -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str123,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str123,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str125,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str125,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str127,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str128,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str127,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str128,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str130,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str131,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str132,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str133,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str134,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str135,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str130,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str131,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str132,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str133,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str134,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str135,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str137,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str137,
       -1, -1, -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str141,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str142,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str143,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str141,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str142,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str143,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str145,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str146,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str147,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str145,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str146,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str147,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str149,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str150,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str151,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str149,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str150,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str151,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str153,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str153,
       -1, -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str156,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str157,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str158,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str159,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str160,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str161,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str162,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str163,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str156,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str157,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str158,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str159,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str160,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str161,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str162,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str163,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str165,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str166,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str167,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str165,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str166,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str167,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str169,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str170,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str171,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str169,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str170,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str171,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str173,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str174,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str175,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str173,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str174,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str175,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str177,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str178,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str179,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str180,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str181,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str182,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str183,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str184,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str177,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str178,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str179,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str180,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str181,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str182,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str183,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str184,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str186,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str187,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str188,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str189,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str190,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str191,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str186,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str187,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str188,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str189,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str190,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str191,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str193,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str193,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str195,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str196,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str197,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str198,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str199,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str200,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str195,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str196,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str197,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str198,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str199,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str200,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str202,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str203,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str204,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str205,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str206,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str207,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str208,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str209,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str210,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str211,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str212,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str213,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str214,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str215,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str202,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str203,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str204,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str205,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str206,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str207,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str208,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str209,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str210,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str211,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str212,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str213,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str214,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str215,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str217,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str218,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str219,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str220,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str221,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str222,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str223,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str224,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str225,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str226,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str227,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str217,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str218,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str219,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str220,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str221,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str222,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str223,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str224,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str225,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str226,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str227,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str229,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str230,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str231,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str229,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str230,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str231,
       -1, -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str234,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str235,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str236,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str237,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str234,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str235,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str236,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str237,
       -1, -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str240,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str241,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str242,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str240,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str241,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str242,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str244,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str245,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str246,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str247,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str248,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str249,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str250,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str251,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str252,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str253,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str254,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str255,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str244,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str245,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str246,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str247,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str248,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str249,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str250,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str251,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str252,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str253,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str254,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str255,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str257,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str258,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str259,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str260,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str261,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str262,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str257,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str258,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str259,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str260,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str261,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str262,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str264,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str265,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str266,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str267,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str264,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str265,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str266,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str267,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str269,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str270,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str269,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str270,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str272,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str273,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str272,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str273,
       -1, -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str276,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str277,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str278,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str276,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str277,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str278,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str280,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str281,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str280,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str281,
       -1, -1, -1, -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str286,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str286,
       -1, -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str289,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str289,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str291,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str291,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str293,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str293,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str295,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str296,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str297,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str298,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str295,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str296,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str297,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str298,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str300,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str300,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str302,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str303,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str304,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str302,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str303,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str304,
       -1, -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str307,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str308,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str309,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str307,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str308,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str309,
       -1, -1, -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str313,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str313,
       -1, -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str316,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str316,
       -1, -1, -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str320,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str320,
       -1, -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str323,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str324,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str323,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str324,
       -1, -1, -1, -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str329,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str329,
       -1, -1, -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str333,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str334,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str335,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str333,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str334,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str335,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str337,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str338,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str337,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str338,
       -1, -1, -1, -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str343,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str343,
       -1, -1, -1, -1, -1, -1, -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str351,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str351,
       -1, -1, -1, -1, -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str357,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str357,
       -1, -1, -1, -1, -1, -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str364,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str365,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str364,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str365,
       -1, -1, -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str369,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str369,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str371,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str371,
       -1, -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str374,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str375,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str376,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str374,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str375,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str376,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str378,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str378,
       -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str388,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str388,
       -1, -1, -1, -1, -1, -1, -1, -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str397,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str397,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str399,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str400,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str399,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str400,
       -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str414,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str414,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str416,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str416,
       -1, -1, -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str420,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str420,
       -1, -1, -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str424,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str424,
       -1, -1, -1, -1, -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str430,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str430,
       -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str441,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str441,
       -1, -1, -1, -1, -1, -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str448,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str448,
       -1, -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str451,
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str451,
       -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      (int)(long)&((struct stringpool_t *)0)->stringpool_str461
+      (int)(size_t)&((struct stringpool_t *)0)->stringpool_str461
     };
 
   if (len <= MAX_WORD_LENGTH && len >= MIN_WORD_LENGTH)
     {
-      register int key = uc_locale_language_hash (str, len);
+      register unsigned int key = uc_locale_language_hash (str, len);
 
-      if (key <= MAX_HASH_VALUE && key >= 0)
+      if (key <= MAX_HASH_VALUE)
         if (len == lengthtable[key])
           {
             register const char *s = wordlist[key] + stringpool;
@@ -1032,7 +1036,7 @@ uc_locale_languages_lookup (register const char *str, register unsigned int len)
     }
   return 0;
 }
-#line 271 "./unicase/locale-languages.gperf"
+#line 295 "../../lib/unicase/locale-languages.gperf"
 
 /*
  * Local Variables:
