@@ -1,28 +1,27 @@
 /* Properties of Unicode characters.
-   Copyright (C) 2007, 2011-2016 Free Software Foundation, Inc.
+   Copyright (C) 2007, 2011-2024 Free Software Foundation, Inc.
    Written by Bruno Haible <bruno@clisp.org>, 2007.
 
-   This program is free software: you can redistribute it and/or
-   modify it under the terms of either:
+   This file is free software.
+   It is dual-licensed under "the GNU LGPLv3+ or the GNU GPLv2+".
+   You can redistribute it and/or modify it under either
+     - the terms of the GNU Lesser General Public License as published
+       by the Free Software Foundation, either version 3, or (at your
+       option) any later version, or
+     - the terms of the GNU General Public License as published by the
+       Free Software Foundation; either version 2, or (at your option)
+       any later version, or
+     - the same dual license "the GNU LGPLv3+ or the GNU GPLv2+".
 
-     * the GNU Lesser General Public License as published by the Free
-       Software Foundation; either version 3 of the License, or (at your
-       option) any later version.
-
-   or
-
-     * the GNU General Public License as published by the Free
-       Software Foundation; either version 2 of the License, or (at your
-       option) any later version.
-
-   or both in parallel, as here.
-   This program is distributed in the hope that it will be useful,
+   This file is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Lesser General Public License for more details.
+   Lesser General Public License and the GNU General Public License
+   for more details.
 
-   You should have received a copy of the GNU Lesser General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
+   You should have received a copy of the GNU Lesser General Public
+   License and of the GNU General Public License along with this
+   program.  If not, see <https://www.gnu.org/licenses/>.  */
 
 #include <config.h>
 
@@ -70,6 +69,8 @@ enum
   UC_PROPERTY_INDEX_OTHER_ID_CONTINUE,
   UC_PROPERTY_INDEX_XID_START,
   UC_PROPERTY_INDEX_XID_CONTINUE,
+  UC_PROPERTY_INDEX_ID_COMPAT_MATH_START,
+  UC_PROPERTY_INDEX_ID_COMPAT_MATH_CONTINUE,
   UC_PROPERTY_INDEX_PATTERN_WHITE_SPACE,
   UC_PROPERTY_INDEX_PATTERN_SYNTAX,
   /* Shaping and rendering.  */
@@ -103,6 +104,7 @@ enum
   UC_PROPERTY_INDEX_IDEOGRAPHIC,
   UC_PROPERTY_INDEX_UNIFIED_IDEOGRAPH,
   UC_PROPERTY_INDEX_RADICAL,
+  UC_PROPERTY_INDEX_IDS_UNARY_OPERATOR,
   UC_PROPERTY_INDEX_IDS_BINARY_OPERATOR,
   UC_PROPERTY_INDEX_IDS_TRINARY_OPERATOR,
   /* Misc.  */
@@ -111,6 +113,7 @@ enum
   UC_PROPERTY_INDEX_NON_BREAK,
   UC_PROPERTY_INDEX_ISO_CONTROL,
   UC_PROPERTY_INDEX_FORMAT_CONTROL,
+  UC_PROPERTY_INDEX_PREPENDED_CONCATENATION_MARK,
   UC_PROPERTY_INDEX_DASH,
   UC_PROPERTY_INDEX_HYPHEN,
   UC_PROPERTY_INDEX_PUNCTUATION,
@@ -228,6 +231,10 @@ uc_property_byname (const char *property_name)
         return UC_PROPERTY_XID_START;
       case UC_PROPERTY_INDEX_XID_CONTINUE:
         return UC_PROPERTY_XID_CONTINUE;
+      case UC_PROPERTY_INDEX_ID_COMPAT_MATH_START:
+        return UC_PROPERTY_ID_COMPAT_MATH_START;
+      case UC_PROPERTY_INDEX_ID_COMPAT_MATH_CONTINUE:
+        return UC_PROPERTY_ID_COMPAT_MATH_CONTINUE;
       case UC_PROPERTY_INDEX_PATTERN_WHITE_SPACE:
         return UC_PROPERTY_PATTERN_WHITE_SPACE;
       case UC_PROPERTY_INDEX_PATTERN_SYNTAX:
@@ -286,6 +293,8 @@ uc_property_byname (const char *property_name)
         return UC_PROPERTY_UNIFIED_IDEOGRAPH;
       case UC_PROPERTY_INDEX_RADICAL:
         return UC_PROPERTY_RADICAL;
+      case UC_PROPERTY_INDEX_IDS_UNARY_OPERATOR:
+        return UC_PROPERTY_IDS_UNARY_OPERATOR;
       case UC_PROPERTY_INDEX_IDS_BINARY_OPERATOR:
         return UC_PROPERTY_IDS_BINARY_OPERATOR;
       case UC_PROPERTY_INDEX_IDS_TRINARY_OPERATOR:
@@ -300,6 +309,8 @@ uc_property_byname (const char *property_name)
         return UC_PROPERTY_ISO_CONTROL;
       case UC_PROPERTY_INDEX_FORMAT_CONTROL:
         return UC_PROPERTY_FORMAT_CONTROL;
+      case UC_PROPERTY_INDEX_PREPENDED_CONCATENATION_MARK:
+        return UC_PROPERTY_PREPENDED_CONCATENATION_MARK;
       case UC_PROPERTY_INDEX_DASH:
         return UC_PROPERTY_DASH;
       case UC_PROPERTY_INDEX_HYPHEN:
